
# This file was generated by 'versioneer.py' (0.7+) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

version_version = '1.1.8'
version_full = '73f7315808931c7a7e93c144bfc08eca5c2f9b4d'
def get_versions(default={}, verbose=False):
    return {'version': version_version, 'full': version_full}

